==> larus_board-1.1.0.zip: larus_board-1.1.0/setup/lang.de.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$XFSLANG = array(
'please_activate_javascript'=>'Bitte aktiviere Javscript in deinem Browser damit die Installation korrekt funktioniert!',
'begin'=>'Beginn',
'precheck'=>'Pfad festlegen',
'select'=>'Parameter festlegen',
'end'=>'Ende',
'license_information'=>'Lizenz-Bedingungen',
'notice'=>'Hinweis',
'development_version'=>'Dies ist eine Testversion und nicht für den Produktiveinsatz gedacht! Es ist gut möglich,
daß du auf unbekannte Fehler triffst, welche sogar mit Datenverlust enden können.',
'php_is_newer_than_tested'=>'Deine PHP-Version ist neuer als jene, die mit "Larus Board" getestet wurden. Dies
<u><i>kann</i></u> zu Problemen führen, wenn der Versionsunterschied all zu groß ist.',
'license'=>'Diese Software ist "Freie Software" im Sinne der
<a href="http://www.gnu.org/philosophy/free-sw.html" target="_blank">Free Software Foundation</a>
von Februar 1986 und gewährt allen Benutzern, die eine Kopie erhalten, vier Freiheiten:
<ul>
<li>Freiheit 1:<br /><strong>Die Freiheit das Programm für jeden erdenklichen Zweck auszuführen.</strong></li>
<li>Freiheit 2:<br /><strong>Die Freiheit das Programm zu studieren und zu ändern.</strong></li>
<li>Freiheit 3:<br /><strong>Die Freiheit das Programm zu kopieren, um deinen Nächsten zu helfen.</strong></li>
<li>Freiheit 4:<br /><strong>Die Freiheit das Programm zu verbessern und diese zu veröffentlichen,
damit die gesamte Gemeinheit davon profitiert.</strong></li>
</ul><hr />
<em>Diese Software verwendet eine Dual-Lizenz. Welche der beiden auf den betreffenden Dateityp zutrifft, entnimmst
du der "LICENSE.DE.html" im Wurzelverzeichnis des heruntergeladenen Archivs, einer eventuell vorhandenen
"license.txt" im betreffenden Unterordner oder auf unserer Webseite, die ganz unten verlinkt ist (klicke dort auf
"Homepage" in der oberen Navigation).</em><hr />
<strong>Geänderte BSD Lizenz</strong><br />
Copyright (c) 2008,2009, The Larus Board Team<br />
Alle Rechte vorbehalten.<br /><br />
Weiterverbreitung und Verwendung in nichtkompilierter oder kompilierter Form, mit oder ohne Veränderung, sind
unter den folgenden Bedingungen zulässig:
<ul>
<li>Weiterverbreitete nichtkompilierte Exemplare müssen das obige Copyright, die Liste der Bedingungen und den
folgenden Haftungsausschluss im Quelltext enthalten.</li>
<li>Weiterverbreitete kompilierte Exemplare müssen das obige Copyright, die Liste der Bedingungen und den folgenden
Haftungsausschluss in der Dokumentation und/oder anderen Materialien, die mit dem Exemplar verbreitet werden, enthalten.</li>
<li>Weder der Name des "The Larus Board Team" noch die Namen der Beitragsleistenden dürfen zum Kennzeichnen oder Bewerben
von Produkten, die von dieser Software abgeleitet wurden, ohne spezielle vorherige schriftliche Genehmigung verwendet werden.</li>
</ul>
DIESE SOFTWARE WIRD VOM VERWALTUNGSRAT UND DEN BEITRAGSLEISTENDEN OHNE JEGLICHE SPEZIELLE ODER IMPLIZIERTE GARANTIEN ZUR
VERFÜGUNG GESTELLT, DIE UNTER ANDEREM EINSCHLIESSEN: DIE IMPLIZIERTE GARANTIE DER VERWENDBARKEIT DER SOFTWARE FÜR EINEN BESTIMMTEN
ZWECK. AUF KEINEN FALL SIND DIE VERWALTUNGSRÄTE ODER DIE BEITRAGSLEISTENDEN FÜR IRGENDWELCHE DIREKTEN, INDIREKTEN, ZUFÄLLIGEN,
SPEZIELLEN, BEISPIELHAFTEN ODER FOLGENDEN SCHÄDEN (UNTER ANDEREM VERSCHAFFEN VON ERSATZGÜTERN ODER -DIENSTLEISTUNGEN; EINSCHRÄNKUNG
DER NUTZUNGSFÄHIGKEIT; VERLUST VON NUTZUNGSFÄHIGKEIT; DATEN; PROFIT ODER GESCHÄFTSUNTERBRECHUNG), WIE AUCH IMMER VERURSACHT UND
UNTER WELCHER VERPFLICHTUNG AUCH IMMER, OB IN VERTRAG, STRIKTER VERPFLICHTUNG ODER UNERLAUBTE HANDLUNG (INKLUSIVE FAHRLÄSSIGKEIT)
VERANTWORTLICH, AUF WELCHEM WEG SIE AUCH IMMER DURCH DIE BENUTZUNG DIESER SOFTWARE ENTSTANDEN SIND, SOGAR, WENN SIE AUF DIE MÖGLICHKEIT
EINES SOLCHEN SCHADENS HINGEWIESEN WORDEN SIND.<hr />
<strong>Creative Commons Attribution-Share Alike 3.0</strong><br />
Es ist ihnen gestattet:<ul>
<li>das Werk vervielfältigen, verbreiten und öffentlich zugänglich machen</li>
<li>Abwandlungen bzw. Bearbeitungen des Inhaltes anfertigen</li>
</ul>
Zu den folgenden Bedingungen:<ul>
<li>Namensnennung. Sie müssen den Namen des Autors/Rechteinhabers in der von ihm festgelegten Weise nennen.
Was bedeutet "Namensnennung" genau? Die zuvor angezeigte Webseite enthielt eingebettete Meta-Daten, unter anderem auch
zur Frage, wie die Namensnennung des Lizenzgebers genau erfolgen soll. Sie können daher das hier angezeigte HTML benutzen,
um den lizenzierten Inhalt zu zitieren. Dadurch werden auch auf Ihrer Webseite Meta-Daten eingebettet, durch die das
Auffinden des verwendeten Inhalts erleichtert wird.</li>
<li>Weitergabe unter gleichen Bedingungen. Wenn Sie den lizenzierten Inhalt bearbeiten oder in anderer Weise umgestalten,
verändern oder als Grundlage für ein andere Inhalte verwenden, dürfen Sie die neu entstandenen Inhalte nur unter Verwendung
von Lizenzbedingungen weitergeben, die mit denen dieses Lizenzvertrages identisch, vergleichbar oder kompatibel sind.</li>
<li>Im Falle einer Verbreitung müssen Sie anderen die Lizenzbedingungen, unter welche dieses Werk fällt, mitteilen. Am
Einfachsten ist es, einen Link auf diese Seite einzubinden.</li>
<li>Jede der vorgenannten Bedingungen kann aufgehoben werden, sofern Sie die Einwilligung des Rechteinhabers dazu erhalten.</li>
<li>Diese Lizenz lässt die Urheberpersönlichkeitsrechte unberührt.</li>
</ul>',
'i_agree'=>'Ich akzeptiere diese Bedingungen',
'php_version'=>'PHP Version',
'php_module'=>'PHP Modul',
'php_module_mandatory'=>'erforderlich',
'php_module_optional'=>'optional',
'req_explain_php_version'=>'Mindestens die PHP-Version 5.2.0 wird benötigt, um das "Larus Board" auszuführen',
'req_explain_php_module_pcre'=>'PCRE findet Muster in Zeichenketten und ist weit verbreitet',
'req_explain_php_module_filter'=>'Dies wird benutzt um Benutzereingaben von schäflichen Inhalten zu filtern',
'req_explain_php_module_pdo'=>'PDO bietet eine generische Schnittstelle zur Datenbankkommunikation',
'req_explain_php_module_pdo_mysql'=>'Ein PDO-Treiber für MySQL',
'req_explain_php_module_pdo_pgsql'=>'Ein PDO-Treiber für PostgreSQL',
'req_explain_php_module_session'=>'Speichert Benutzerdaten während einer Anmeldung',
'req_explain_php_module_date'=>'Berechnet verschiedene Zeitzonen und Datumformate',
'req_explain_php_module_gd'=>'Malt dynamische Bitmap-Grafiken',
'req_explain_php_module_zlib'=>'Komprimiert HTML-Ausgabe für Clients/Browser',
'req_explain_php_module_hash'=>'Erlaubt es sichere Hashes für die Kennwortlagerung zu verwenden',
'req_explain_php_module_mcrypt'=>'Bietet Kryptografieroutinen zur Ver-/Entschlüsselung',
'req_explain_php_module_gnupg'=>'Bindet gnupg an, um E-Mails zu signieren',
'req_explain_php_module_simplexml'=>'Einfache Methode um XML-formatierte Dateien wie RSS-Feeds zu verarbeiten',
'req_explain_php_module_suhosin'=>'Erhöht die Sicherheit des PHP-Kerns',
'back'=>'Zurück',
'no'=>'nein',
'yes'=>'ja',
'initial_environment_detection'=>'Beginne mit der Umgebungserkennung',
'detected_root_path'=>'Erkannter Pfad zum "Öffentlichen"',
'detected_root_uri'=>'Erkannter URI zum "Öffentlichen"',
'if_correct_go_on'=>'Sofern die Angaben korrekt sind, klicke hier um fortzufahren...',
'repair_options'=>'Reparatur-Optionen',
'root_uri'=>'Wurzel-URI vom "Öffentlichen"',
'root_path'=>'Wurzel-Pfad vom "Privaten"',
'root_class_not_found'=>'Fehler: Die class.root.php konnte nicht in "Privat" gefunden werden. Vielleicht
hast du den falschen Pfad angegeben?',
'folder_not_writeable'=>'Hinweis: Ordner "%s" ist schreibgeschützt!',
'file_not_writeable'=>'Hinweis: Datei "%s" ist schreibgeschützt!',
'form_values_error'=>'Du hast nicht alle Felder korrekt ausgefüllt.',
'setup_type'=>'Was möchtest du gerne tun?',
'source_database'=>'Datenbank-Information für die Quell Forum-Software',
'target_database'=>'Datenbank-Informationen für das "Larus Board"',
'install'=>'Frische/Reparatur Installation',
'update'=>'Bestehende Installation aktualisieren',
'convert'=>'Von anderer Software konvertieren',
'installation_complete'=>'Die Installation ist abgeschlossen',
'current_core_version'=>'LB-Kern meldet die Version',
'current_database_version'=>'Aktuelle Datenbank-Versionsnummer ist',
'recent_database_version'=>'Neueste Datenbank-Versionsnummer ist',
'forum_is_in_maintenance_mode'=>'Forum befindet sich im Wartungsmodus',
'enable_maintenance_mode'=>'In Wartungsmodus versetzen',
'disable_maintenance_mode'=>'In Normalmodus versetzen',
'perform_update'=>'Aktualisierungen durchführen',
'all_updates_were_applied'=>'Alle verfügbaren Aktualisierungen wurden ausgeführt.',
'updates_are_prepared'=>'Aktualisierungen werden vorbereitet...',
'update_explain'=>'Hast du die <a href="../INSTALL.DE.html" target="_blank">Dokumentation</a> in Bezug auf Aktualisierungen gelesen?',
'update_description'=>'<strong>Aktualisierung gefunden</strong> - Version %d "%s"...',
'update_preparing'=>'Vorbereiten',
'update_running'=>'Konfiguriere',
'update_cleaning'=>'Räume auf',
'update_ok'=>'OK',
'update_fail'=>'Fehlschlag',
'update_skip'=>'Übersprungen',
'update_applied'=>'Die Aktualisierung wurde ausgeführt. Bitte <a href="index.php?step=9">lade die Seite neu</a>.',
'update_complete'=>'Die Aktualisierung ist abgeschlossen',
'reset_a_password'=>'Ein Kennwort zurücksetzen',
'rebuild_passwords'=>'Alle Kennwörter erneuern',
'edit_configuration'=>'Konfiguration bearbeiten',
'purge_local_cache'=>'Lokalen Zwischenspeicher löschen',
'verify_database_integrity'=>'Datenbankintegrität prüfen',
'db_type'=>'Datenbank-Typ',
'db_host'=>'Datenbank-Host',
'db_username'=>'Datenbank-Benutzername',
'db_password'=>'Datenbank-Kennwort (darf nicht leer sein)',
'db_name'=>'Datenbank-Name',
'db_prefix'=>'Datenbank-Tabellenpräfix',
'guest_username'=>'ID des "Gast-Benutzers"',
'admin_name'=>'Benutzername des Verwalters (3-32 Zeichen, nur bei Installation/Reparatur)',
'admin_password'=>'Kennwort des Verwalters (5+ Zeichen, nur bei Installation/Reparatur)',
'database_connection_check'=>'Prüfe die Datenbank-Verbindung',
'database_server_version'=>'Die Version der Server-Software ist',
'configuration_file_not_writeable'=>'Wir konnten ihre Konfigurationsdatei nicht beschreiben!',
'source_forum_software'=>'Wähle eine Software aus von der du konvertieren möchtest',
'mysql_is_too_old'=>'Deine MySQL-Version ist zu alt - aktualisiere wenigstens nach 4.1.0!',
'explain_password_rehashing'=>'Du kannst hier jedem Mitglied ein neues Kennwort zuweisen. Es wird an die jeweils
hinterlegte E-Mail Adresse gesendet.<br />
Falls dieser Prozess mit einem Timeout abbricht, lade die Seite einfach neu. Fehlende Kennwörter werden
solange erzeugt bis alle fertig sind.',
'new_password'=>'Neues Kennwort',
'password_rehashing_complete'=>'Die Kennwörter deiner Mitglieder sind nun erneuert.',
'explain_verify_database_integrity'=>'Du kannst hier die Integrität deiner Datenbank prüfen. Es untersucht die Beziehungen
zwischen den Tabellen.<br />
Falls dieser Prozess mit einem Timeout abbricht, lade die Seite einfach neu. Alle fehlenden Tests werden
fortgeführt bis alle fertig sind.',
'database_integrity_check_step'=>'<strong>Beginne mit dem Test "%s" des Protokolls</strong><br />',
'database_integrity_skip_step'=>'<strong>Überspringe Test "%s" da er bereits erledigt wurde</strong><br />',
'dic_insert_acl'=>'&nbsp;&nbsp;&nbsp;· Füge neue ACL für Aktion "%s" mit der Gruppen-ID %d ein<br />',
'dic_update_post_data'=>'&nbsp;&nbsp;&nbsp;· Setze Benutzer-ID auf 1 für den Beitrag %d (Daten-Sektion)<br />',
'dic_update_post_meta'=>'&nbsp;&nbsp;&nbsp;· Setze Benutzer-ID auf 1 für den Beitrag %d (Meta-Sektion)<br />',
'dic_update_user_group'=>'&nbsp;&nbsp;&nbsp;· Setze Gruppen-ID auf 1 für Benutzer-ID %d<br />',
'database_integrity_check_complete'=>'Deine Datenbank-Integrität wurde überprüft.',
'explain_reset_a_password'=>'Du kannst hier das Kennwort eines einzelnen Mitglieds rücksetzen.',
'username_or_userid'=>'Benutzername oder numerische ID',
'password'=>'Neues Kennwort',
'please_repeat'=>'Bitte wiederholen',
'passwords_are_not_equal'=>'Beide Kennwörter sind ungleich',
'reset_a_password_complete'=>'Das Benutzer-Kennwort ist nun geändert.',
'could_not_set_new_password'=>'Entschuldigung, aber das neue Kennwort wurde nicht gesetzt!',
'explain_edit_configuration'=>'Du kannst hier deine Konfigurationseinstellungen ändern.<br />Aber sei vorsichtig, da diese
nicht geprüft werden.',
'configuration_edit_complete'=>'Das Ändern deiner Konfiguration ist abgeschlossen.',
'explain_purge_local_caches'=>'Du kannst hier deinen gesamten lokalen Zwischenspeicher leeren. Er wird selbständig neu
aufgebaut.',
'purging_local_caches_complete'=>'Dein lokaler Zwischenspeicher ist nun entleert.'
);
?>

==> larus_board-1.1.2.zip: larus_board-1.1.2/setup/lang.de.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009,2010 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$XFSLANG = array(
'please_activate_javascript'=>'Bitte aktiviere Javscript in deinem Browser damit die Installation korrekt funktioniert!',
'begin'=>'Beginn',
'precheck'=>'Pfad festlegen',
'select'=>'Parameter festlegen',
'end'=>'Ende',
'license_information'=>'Lizenz-Bedingungen',
'notice'=>'Hinweis',
'development_version'=>'Dies ist eine Testversion und nicht für den Produktiveinsatz gedacht! Es ist gut möglich,
daß du auf unbekannte Fehler triffst, welche sogar mit Datenverlust enden können.',
'php_is_newer_than_tested'=>'Deine PHP-Version ist neuer als jene, die mit "Larus Board" getestet wurden. Dies
<u><i>kann</i></u> zu Problemen führen, wenn der Versionsunterschied all zu groß ist.',
'license'=>'Diese Software ist "Freie Software" im Sinne der
<a href="http://www.gnu.org/philosophy/free-sw.html" target="_blank">Free Software Foundation</a>
von Februar 1986 und gewährt allen Benutzern, die eine Kopie erhalten, vier Freiheiten:
<ul>
<li>Freiheit 1:<br /><strong>Die Freiheit das Programm für jeden erdenklichen Zweck auszuführen.</strong></li>
<li>Freiheit 2:<br /><strong>Die Freiheit das Programm zu studieren und zu ändern.</strong></li>
<li>Freiheit 3:<br /><strong>Die Freiheit das Programm zu kopieren, um deinen Nächsten zu helfen.</strong></li>
<li>Freiheit 4:<br /><strong>Die Freiheit das Programm zu verbessern und diese zu veröffentlichen,
damit die gesamte Gemeinheit davon profitiert.</strong></li>
</ul><hr />
<em>Diese Software verwendet eine Dual-Lizenz. Welche der beiden auf den betreffenden Dateityp zutrifft, entnimmst
du der "LICENSE.DE.html" im Wurzelverzeichnis des heruntergeladenen Archivs, einer eventuell vorhandenen
"license.txt" im betreffenden Unterordner oder auf unserer Webseite, die ganz unten verlinkt ist (klicke dort auf
"Homepage" in der oberen Navigation).</em><hr />
<strong>Geänderte BSD Lizenz</strong><br />
Copyright (c) 2008,2009,2010 by The Larus Board Team<br />
Alle Rechte vorbehalten.<br /><br />
Weiterverbreitung und Verwendung in nichtkompilierter oder kompilierter Form, mit oder ohne Veränderung, sind
unter den folgenden Bedingungen zulässig:
<ul>
<li>Weiterverbreitete nichtkompilierte Exemplare müssen das obige Copyright, die Liste der Bedingungen und den
folgenden Haftungsausschluss im Quelltext enthalten.</li>
<li>Weiterverbreitete kompilierte Exemplare müssen das obige Copyright, die Liste der Bedingungen und den folgenden
Haftungsausschluss in der Dokumentation und/oder anderen Materialien, die mit dem Exemplar verbreitet werden, enthalten.</li>
<li>Weder der Name des "The Larus Board Team" noch die Namen der Beitragsleistenden dürfen zum Kennzeichnen oder Bewerben
von Produkten, die von dieser Software abgeleitet wurden, ohne spezielle vorherige schriftliche Genehmigung verwendet werden.</li>
</ul>
DIESE SOFTWARE WIRD VOM VERWALTUNGSRAT UND DEN BEITRAGSLEISTENDEN OHNE JEGLICHE SPEZIELLE ODER IMPLIZIERTE GARANTIEN ZUR
VERFÜGUNG GESTELLT, DIE UNTER ANDEREM EINSCHLIESSEN: DIE IMPLIZIERTE GARANTIE DER VERWENDBARKEIT DER SOFTWARE FÜR EINEN BESTIMMTEN
ZWECK. AUF KEINEN FALL SIND DIE VERWALTUNGSRÄTE ODER DIE BEITRAGSLEISTENDEN FÜR IRGENDWELCHE DIREKTEN, INDIREKTEN, ZUFÄLLIGEN,
SPEZIELLEN, BEISPIELHAFTEN ODER FOLGENDEN SCHÄDEN (UNTER ANDEREM VERSCHAFFEN VON ERSATZGÜTERN ODER -DIENSTLEISTUNGEN; EINSCHRÄNKUNG
DER NUTZUNGSFÄHIGKEIT; VERLUST VON NUTZUNGSFÄHIGKEIT; DATEN; PROFIT ODER GESCHÄFTSUNTERBRECHUNG), WIE AUCH IMMER VERURSACHT UND
UNTER WELCHER VERPFLICHTUNG AUCH IMMER, OB IN VERTRAG, STRIKTER VERPFLICHTUNG ODER UNERLAUBTE HANDLUNG (INKLUSIVE FAHRLÄSSIGKEIT)
VERANTWORTLICH, AUF WELCHEM WEG SIE AUCH IMMER DURCH DIE BENUTZUNG DIESER SOFTWARE ENTSTANDEN SIND, SOGAR, WENN SIE AUF DIE MÖGLICHKEIT
EINES SOLCHEN SCHADENS HINGEWIESEN WORDEN SIND.<hr />
<strong>Creative Commons Attribution-Share Alike 3.0</strong><br />
Es ist ihnen gestattet:<ul>
<li>das Werk vervielfältigen, verbreiten und öffentlich zugänglich machen</li>
<li>Abwandlungen bzw. Bearbeitungen des Inhaltes anfertigen</li>
</ul>
Zu den folgenden Bedingungen:<ul>
<li>Namensnennung. Sie müssen den Namen des Autors/Rechteinhabers in der von ihm festgelegten Weise nennen.
Was bedeutet "Namensnennung" genau? Die zuvor angezeigte Webseite enthielt eingebettete Meta-Daten, unter anderem auch
zur Frage, wie die Namensnennung des Lizenzgebers genau erfolgen soll. Sie können daher das hier angezeigte HTML benutzen,
um den lizenzierten Inhalt zu zitieren. Dadurch werden auch auf Ihrer Webseite Meta-Daten eingebettet, durch die das
Auffinden des verwendeten Inhalts erleichtert wird.</li>
<li>Weitergabe unter gleichen Bedingungen. Wenn Sie den lizenzierten Inhalt bearbeiten oder in anderer Weise umgestalten,
verändern oder als Grundlage für ein andere Inhalte verwenden, dürfen Sie die neu entstandenen Inhalte nur unter Verwendung
von Lizenzbedingungen weitergeben, die mit denen dieses Lizenzvertrages identisch, vergleichbar oder kompatibel sind.</li>
<li>Im Falle einer Verbreitung müssen Sie anderen die Lizenzbedingungen, unter welche dieses Werk fällt, mitteilen. Am
Einfachsten ist es, einen Link auf diese Seite einzubinden.</li>
<li>Jede der vorgenannten Bedingungen kann aufgehoben werden, sofern Sie die Einwilligung des Rechteinhabers dazu erhalten.</li>
<li>Diese Lizenz lässt die Urheberpersönlichkeitsrechte unberührt.</li>
</ul>',
'i_agree'=>'Ich akzeptiere diese Bedingungen',
'php_version'=>'PHP Version',
'php_module'=>'PHP Modul',
'php_module_mandatory'=>'erforderlich',
'php_module_optional'=>'optional',
'req_explain_php_version'=>'Mindestens die PHP-Version 5.2.0 wird benötigt, um das "Larus Board" auszuführen',
'req_explain_php_module_pcre'=>'PCRE findet Muster in Zeichenketten und ist weit verbreitet',
'req_explain_php_module_filter'=>'Dies wird benutzt um Benutzereingaben von schädlichen Inhalten zu filtern',
'req_explain_php_module_pdo'=>'PDO bietet eine generische Schnittstelle zur Datenbankkommunikation',
'req_explain_php_module_pdo_mysql'=>'Ein PDO-Treiber für MySQL',
'req_explain_php_module_pdo_pgsql'=>'Ein PDO-Treiber für PostgreSQL',
'req_explain_php_module_session'=>'Speichert Benutzerdaten während einer Anmeldung',
'req_explain_php_module_date'=>'Berechnet verschiedene Zeitzonen und Datumformate',
'req_explain_php_module_gd'=>'Malt dynamische Bitmap-Grafiken',
'req_explain_php_module_zlib'=>'Komprimiert HTML-Ausgabe für Clients/Browser',
'req_explain_php_module_hash'=>'Erlaubt es sichere Hashes für die Kennwortlagerung zu verwenden',
'req_explain_php_module_mcrypt'=>'Bietet Kryptografieroutinen zur Ver-/Entschlüsselung',
'req_explain_php_module_gnupg'=>'Bindet gnupg an, um E-Mails zu signieren',
'req_explain_php_module_simplexml'=>'Einfache Methode um XML-formatierte Dateien wie RSS-Feeds zu verarbeiten',
'req_explain_php_module_suhosin'=>'Erhöht die Sicherheit des PHP-Kerns',
'back'=>'Zurück',
'no'=>'nein',
'yes'=>'ja',
'initial_environment_detection'=>'Beginne mit der Umgebungserkennung',
'detected_root_path'=>'Erkannter Pfad zum "Öffentlichen"',
'detected_root_uri'=>'Erkannter URI zum "Öffentlichen"',
'if_correct_go_on'=>'Sofern die Angaben korrekt sind, klicke hier um fortzufahren...',
'repair_options'=>'Reparatur-Optionen',
'root_uri'=>'Wurzel-URI vom "Öffentlichen"',
'root_path'=>'Wurzel-Pfad vom "Privaten"',
'root_class_not_found'=>'Fehler: Die class.root.php konnte nicht in "Privat" gefunden werden. Vielleicht
hast du den falschen Pfad angegeben?',
'folder_not_writeable'=>'Hinweis: Ordner "%s" ist schreibgeschützt!',
'file_not_writeable'=>'Hinweis: Datei "%s" ist schreibgeschützt!',
'form_values_error'=>'Du hast nicht alle Felder korrekt ausgefüllt.',
'setup_type'=>'Was möchtest du gerne tun?',
'source_database'=>'Datenbank-Information für die Quell Forum-Software',
'target_database'=>'Datenbank-Informationen für das "Larus Board"',
'install'=>'Frische/Reparatur Installation',
'update'=>'Bestehende Installation aktualisieren',
'convert'=>'Von anderer Software konvertieren',
'installation_complete'=>'Die Installation ist abgeschlossen',
'current_core_version'=>'LB-Kern meldet die Version',
'current_database_version'=>'Aktuelle Datenbank-Versionsnummer ist',
'recent_database_version'=>'Neueste Datenbank-Versionsnummer ist',
'forum_is_in_maintenance_mode'=>'Forum befindet sich im Wartungsmodus',
'enable_maintenance_mode'=>'In Wartungsmodus versetzen',
'disable_maintenance_mode'=>'In Normalmodus versetzen',
'perform_update'=>'Aktualisierungen durchführen',
'all_updates_were_applied'=>'Alle verfügbaren Aktualisierungen wurden ausgeführt.',
'updates_are_prepared'=>'Aktualisierungen werden vorbereitet...',
'update_explain'=>'Hast du die <a href="../INSTALL.DE.html" target="_blank">Dokumentation</a> in Bezug auf Aktualisierungen gelesen?',
'update_description'=>'<strong>Aktualisierung gefunden</strong> - Version %d "%s"...',
'update_preparing'=>'Vorbereiten',
'update_running'=>'Konfiguriere',
'update_cleaning'=>'Räume auf',
'update_ok'=>'OK',
'update_fail'=>'Fehlschlag',
'update_skip'=>'Übersprungen',
'update_applied'=>'Die Aktualisierung wurde ausgeführt. Bitte <a href="index.php?step=9">lade die Seite neu</a>.',
'update_complete'=>'Die Aktualisierung ist abgeschlossen',
'reset_a_password'=>'Ein Kennwort zurücksetzen',
'rebuild_passwords'=>'Alle Kennwörter erneuern',
'edit_configuration'=>'Konfiguration bearbeiten',
'purge_local_cache'=>'Lokalen Zwischenspeicher löschen',
'verify_database_integrity'=>'Datenbankintegrität prüfen',
'db_type'=>'Datenbank-Typ',
'db_host'=>'Datenbank-Host',
'db_username'=>'Datenbank-Benutzername',
'db_password'=>'Datenbank-Kennwort (darf nicht leer sein)',
'db_name'=>'Datenbank-Name',
'db_prefix'=>'Datenbank-Tabellenpräfix',
'guest_username'=>'ID des "Gast-Benutzers"',
'admin_name'=>'Benutzername des Verwalters (3-32 Zeichen, nur bei Installation/Reparatur)',
'admin_password'=>'Kennwort des Verwalters (5+ Zeichen, nur bei Installation/Reparatur)',
'database_connection_check'=>'Prüfe die Datenbank-Verbindung',
'database_server_version'=>'Die Version der Server-Software ist',
'configuration_file_not_writeable'=>'Wir konnten ihre Konfigurationsdatei nicht beschreiben!',
'source_forum_software'=>'Wähle eine Software aus von der du konvertieren möchtest',
'mysql_is_too_old'=>'Deine MySQL-Version ist zu alt - aktualisiere wenigstens nach 4.1.0!',
'explain_password_rehashing'=>'Du kannst hier jedem Mitglied ein neues Kennwort zuweisen. Es wird an die jeweils
hinterlegte E-Mail Adresse gesendet.<br />
Falls dieser Prozess mit einem Timeout abbricht, lade die Seite einfach neu. Fehlende Kennwörter werden
solange erzeugt bis alle fertig sind.',
'new_password'=>'Neues Kennwort',
'password_rehashing_complete'=>'Die Kennwörter deiner Mitglieder sind nun erneuert.',
'explain_verify_database_integrity'=>'Du kannst hier die Integrität deiner Datenbank prüfen. Es untersucht die Beziehungen
zwischen den Tabellen.<br />
Falls dieser Prozess mit einem Timeout abbricht, lade die Seite einfach neu. Alle fehlenden Tests werden
fortgeführt bis alle fertig sind.',
'database_integrity_check_step'=>'<strong>Beginne mit dem Test "%s" des Protokolls</strong><br />',
'database_integrity_skip_step'=>'<strong>Überspringe Test "%s" da er bereits erledigt wurde</strong><br />',
'dic_insert_acl'=>'&nbsp;&nbsp;&nbsp;· Füge neue ACL für Aktion "%s" mit der Gruppen-ID %d ein<br />',
'dic_update_post_data'=>'&nbsp;&nbsp;&nbsp;· Setze Benutzer-ID auf 1 für den Beitrag %d (Daten-Sektion)<br />',
'dic_update_post_meta'=>'&nbsp;&nbsp;&nbsp;· Setze Benutzer-ID auf 1 für den Beitrag %d (Meta-Sektion)<br />',
'dic_update_user_group'=>'&nbsp;&nbsp;&nbsp;· Setze Gruppen-ID auf 1 für Benutzer-ID %d<br />',
'database_integrity_check_complete'=>'Deine Datenbank-Integrität wurde überprüft.',
'explain_reset_a_password'=>'Du kannst hier das Kennwort eines einzelnen Mitglieds rücksetzen.',
'username_or_userid'=>'Benutzername oder numerische ID',
'password'=>'Neues Kennwort',
'please_repeat'=>'Bitte wiederholen',
'passwords_are_not_equal'=>'Beide Kennwörter sind ungleich',
'reset_a_password_complete'=>'Das Benutzer-Kennwort ist nun geändert.',
'could_not_set_new_password'=>'Entschuldigung, aber das neue Kennwort wurde nicht gesetzt!',
'explain_edit_configuration'=>'Du kannst hier deine Konfigurationseinstellungen ändern.<br />Aber sei vorsichtig, da diese
nicht geprüft werden.',
'configuration_edit_complete'=>'Das Ändern deiner Konfiguration ist abgeschlossen.',
'explain_purge_local_caches'=>'Du kannst hier deinen gesamten lokalen Zwischenspeicher leeren. Er wird selbständig neu
aufgebaut.',
'purging_local_caches_complete'=>'Dein lokaler Zwischenspeicher ist nun entleert.'
);
?>
